@@ -757,6 +757,12 @@ class InvalidParameters(FailedFunctionCall):
 class WrongArgTypes(InvalidParameters):
   """For functions that were called with the wrong types."""
 
+  def __init__(self, sig, passed_args, ctx, bad_param):
+    if not sig.has_param(bad_param.name):
+      sig = sig.insert_varargs_and_kwargs(
+          name for name, *_ in sig.iter_args(passed_args))
+    super().__init__(sig, passed_args, ctx, bad_param)
+
   def __gt__(self, other):
     if other is None:
       return True
@@ -1087,7 +1093,7 @@ def handle_typeguard(node, ret: _ReturnType, first_arg, ctx, func_name=None):
   if not target_name:
     desc = f" function {func_name!r}" if func_name else ""
     ctx.errorlog.not_supported_yet(
-        ctx.vm.frames, f"Using TypeGuard{desc} with an arbitrary expression",
+        ctx.vm.frames, f"Calling TypeGuard{desc} with an arbitrary expression",
         "Please assign the expression to a local variable.")
     return None
   target = frame.lookup_name(target_name)
