@@ -1,12 +1,10 @@
 """Tests for attribute.py."""
 
 from pytype import config
-from pytype import context
-from pytype import errors
-from pytype import load_pytd
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
 from pytype.tests import test_base
+from pytype.tests import test_utils
 
 import unittest
 
@@ -27,8 +25,7 @@ class ValselfTest(test_base.UnitTest):
     super().setUp()
     options = config.Options.create(python_version=self.python_version,
                                     color="never")
-    self.ctx = context.Context(errors.ErrorLog(), options,
-                               load_pytd.Loader(options))
+    self.ctx = test_utils.make_context(options)
     self.node = self.ctx.root_node
     self.attribute_handler = self.ctx.attribute_handler
 
@@ -116,8 +113,7 @@ class AttributeTest(test_base.UnitTest):
   def setUp(self):
     super().setUp()
     options = config.Options.create(python_version=self.python_version)
-    self._ctx = context.Context(errors.ErrorLog(), options,
-                                load_pytd.Loader(options))
+    self._ctx = test_utils.make_context(options)
 
   def test_type_parameter_instance(self):
     t = abstract.TypeParameter(abstract_utils.T, self._ctx)
