@@ -2,15 +2,13 @@
 
 from pytype import compare
 from pytype import config
-from pytype import context
-from pytype import errors
-from pytype import load_pytd
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
 from pytype.abstract import function
 from pytype.pytd import pytd
 from pytype.pytd import slots
 from pytype.tests import test_base
+from pytype.tests import test_utils
 
 import unittest
 
@@ -20,8 +18,7 @@ class CompareTestBase(test_base.UnitTest):
   def setUp(self):
     super().setUp()
     options = config.Options.create(python_version=self.python_version)
-    self._ctx = context.Context(errors.ErrorLog(), options,
-                                load_pytd.Loader(options))
+    self._ctx = test_utils.make_context(options)
     self._program = self._ctx.program
     self._node = self._ctx.root_node.ConnectNew("test_node")
     self._convert = self._ctx.convert
