@@ -5,17 +5,17 @@ import logging
 import types
 from typing import Any, Dict
 
-from pytype import blocks
 from pytype import datatypes
 from pytype import module_utils
-from pytype import special_builtins
 from pytype import utils
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
 from pytype.abstract import mixin
+from pytype.directors import blocks
 from pytype.overlays import attr_overlay
 from pytype.overlays import overlay_dict
 from pytype.overlays import named_tuple
+from pytype.overlays import special_builtins
 from pytype.overlays import typed_dict
 from pytype.overlays import typing_overlay
 from pytype.pyc import loadmarshal
