@@ -1,6 +1,7 @@
 """Support for the 'subprocess' library."""
 
 from pytype.abstract import abstract
+from pytype.abstract import mixin
 from pytype.overlays import overlay
 
 
@@ -15,41 +16,8 @@ class SubprocessOverlay(overlay.Overlay):
     super().__init__(ctx, "subprocess", member_map, ast)
 
 
-class Popen(abstract.PyTDClass):
-  """Custom implementation of subprocess.Popen."""
-
-  class _Unloaded:
-    pass
-
-  def __init__(self, ctx):
-    pyval = ctx.loader.import_name("subprocess").Lookup("subprocess.Popen")
-    super().__init__("Popen", pyval, ctx)
-    # lazily loaded because the signatures refer back to Popen itself
-    self._new = Popen._Unloaded()
-
-  @property
-  def new(self):
-    if isinstance(self._new, Popen._Unloaded):
-      if "__new__" not in self.pytd_cls:
-        self._new = None
-      else:
-        f = self.pytd_cls.Lookup("__new__")
-        sigs = [
-            abstract.PyTDSignature(f.name, sig, self.ctx)
-            for sig in f.signatures
-        ]
-        self._new = PopenNew(f.name, sigs, f.kind, self.ctx)
-    return self._new
-
-  def get_own_new(self, node, value):
-    new = self.new
-    if new:
-      return node, new.to_variable(node)
-    return super().get_own_new(node, value)
-
-
-class PopenNew(abstract.PyTDFunction):
-  """Custom implementation of subprocess.Popen.__new__."""
+class PopenInit(abstract.PyTDFunction):
+  """Custom implementation of subprocess.Popen.__init__."""
 
   def _can_match_multiple(self, args):
     # We need to distinguish between Popen[bytes] and Popen[str]. This requires
@@ -74,3 +42,25 @@ class PopenNew(abstract.PyTDFunction):
       return super()._can_match_multiple(args)
     else:
       return args.has_opaque_starargs_or_starstarargs()
+
+
+class Popen(abstract.PyTDClass, mixin.HasSlots):
+  """Custom implementation of subprocess.Popen."""
+
+  def __init__(self, ctx):
+    pytd_cls = ctx.loader.import_name("subprocess").Lookup("subprocess.Popen")
+    super().__init__("Popen", pytd_cls, ctx)
+    mixin.HasSlots.init_mixin(self)
+    self._setting_init = False  # recursion detection
+
+  def get_special_attribute(self, node, name, valself):
+    if name != "__init__" or self._setting_init:
+      return super().get_special_attribute(node, name, valself)
+    # lazily loaded because the signatures refer back to Popen itself
+    if name not in self._slots:
+      slot = self.ctx.convert.convert_pytd_function(
+          self.pytd_cls.Lookup(name), PopenInit)
+      self._setting_init = True
+      self.set_slot(name, slot)
+      self._setting_init = False
+    return mixin.HasSlots.get_special_attribute(self, node, name, valself)
