@@ -31,11 +31,10 @@ class TestTypeMatch(parser_test_base.ParserTest):
 
   def setUp(self):
     super().setUp()
-    builtins = parser.parse_string(textwrap.dedent(_BUILTINS),
-                                   name="builtins",
-                                   python_version=self.python_version)
-    typing = parser.parse_string("class Generic: ...", name="typing",
-                                 python_version=self.python_version)
+    builtins = parser.parse_string(
+        textwrap.dedent(_BUILTINS), name="builtins", options=self.options)
+    typing = parser.parse_string(
+        "class Generic: ...", name="typing", options=self.options)
     self.mini_builtins = pytd_utils.Concat(builtins, typing)
 
   def LinkAgainstSimpleBuiltins(self, ast):
@@ -126,7 +125,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
     ast = parser.parse_string(textwrap.dedent("""
       def left(a: int) -> int: ...
       def right(a: int) -> int: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     m = type_match.TypeMatch()
     self.assertEqual(m.match(ast.Lookup("left"), ast.Lookup("right"), {}),
                      booleq.TRUE)
@@ -135,7 +134,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
     ast = parser.parse_string(textwrap.dedent("""
       def left(a: int) -> float: ...
       def right(a: int) -> int: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     m = type_match.TypeMatch()
     self.assertNotEqual(m.match(ast.Lookup("left"), ast.Lookup("right"), {}),
                         booleq.TRUE)
@@ -144,7 +143,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
     ast = parser.parse_string(textwrap.dedent("""
       def left(a: int) -> int: ...
       def right(a: int, *args) -> int: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     m = type_match.TypeMatch()
     self.assertEqual(m.match(ast.Lookup("left"), ast.Lookup("right"), {}),
                      booleq.TRUE)
@@ -157,7 +156,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
         pass
       left = ...  # type: A[Any]
       right = ...  # type: A[Any]
-    """), python_version=self.python_version)
+    """), options=self.options)
     ast = self.LinkAgainstSimpleBuiltins(ast)
     m = type_match.TypeMatch()
     self.assertEqual(m.match_type_against_type(
@@ -172,7 +171,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
       class Right():
         def method(self) -> Any: ...
         def method2(self) -> Any: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     ast = visitors.LookupClasses(ast, self.mini_builtins)
     m = type_match.TypeMatch()
     left, right = ast.Lookup("Left"), ast.Lookup("Right")
@@ -188,7 +187,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
       a = ...  # type: A
       def left(a: B) -> B: ...
       def right(a: A) -> A: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     ast = visitors.LookupClasses(ast, self.mini_builtins)
     m = type_match.TypeMatch(type_match.get_all_subclasses([ast]))
     left, right = ast.Lookup("left"), ast.Lookup("right")
@@ -207,7 +206,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
         pass
       def left(x: `~unknown0`) -> Any: ...
       def right(x: A[B]) -> Any: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     ast = self.LinkAgainstSimpleBuiltins(ast)
     m = type_match.TypeMatch()
     left, right = ast.Lookup("left"), ast.Lookup("right")
@@ -239,7 +238,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
       a = ...  # type: A
       def left() -> `~unknown0`: ...
       def right() -> list[A]: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     ast = self.LinkAgainstSimpleBuiltins(ast)
     m = type_match.TypeMatch(type_match.get_all_subclasses([ast]))
     left, right = ast.Lookup("left"), ast.Lookup("right")
@@ -257,7 +256,7 @@ class TestTypeMatch(parser_test_base.ParserTest):
 
       class Match():
         def f(self, x:Base) -> Base: ...
-    """), python_version=self.python_version)
+    """), options=self.options)
     ast = self.LinkAgainstSimpleBuiltins(ast)
     m = type_match.TypeMatch(type_match.get_all_subclasses([ast]))
     eq = m.match_Class_against_Class(ast.Lookup("Match"), ast.Lookup("Foo"), {})
