@@ -158,8 +158,7 @@ class TestCustomOptions(TestBase):
   def assertFlags(self, flags, expected_flags):
     # Add temporary flags that are set to true by default here, so that they are
     # filtered out of tests.
-    temporary_flags = {'--overriding-default-value-checks',
-                       '--overriding-parameter-name-checks'}
+    temporary_flags = {'--overriding-return-type-checks'}
     self.assertEqual(flags - temporary_flags, expected_flags)
 
   # --disable tests a flag with a string value.
