@@ -9,12 +9,12 @@ from typing import Any, Dict, Sequence, Tuple, Union
 
 import attrs
 
-from pytype import special_builtins
 from pytype import state as frame_state
 from pytype import vm
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
 from pytype.abstract import function
+from pytype.overlays import special_builtins
 from pytype.overlays import typing_overlay
 from pytype.pytd import escape
 from pytype.pytd import optimize
@@ -581,9 +581,15 @@ class CallTracer(vm.VirtualMachine):
       elif options:
         for option in options:
           try:
-            d = option.to_pytd_def(self.ctx.exitpoint, name)  # Deep definition
+            # TODO(b/260754211): We should have a specific check for large
+            # literals, rather than trying to filter other things out.
+            should_optimize = not isinstance(option, abstract.FUNCTION_TYPES)
+            with self.ctx.pytd_convert.optimize_literals(should_optimize):
+              # Deep definition
+              d = option.to_pytd_def(self.ctx.exitpoint, name)
           except NotImplementedError:
-            d = option.to_type(self.ctx.exitpoint)  # Type only
+            with self.ctx.pytd_convert.optimize_literals():
+              d = option.to_type(self.ctx.exitpoint)  # Type only
             if isinstance(d, pytd.NothingType):
               if isinstance(option, abstract.Empty):
                 d = pytd.AnythingType()
