@@ -1,6 +1,4 @@
 """Tests for utils.py."""
-import os
-
 from pytype import utils
 
 import unittest
@@ -79,30 +77,6 @@ class UtilsTest(unittest.TestCase):
     with self.assertRaises(utils.UsageError):
       utils.validate_version(python_version)
 
-  def test_parse_interpreter_version(self):
-    test_cases = (
-        ("Python 3.8.3", (3, 8)),
-        ("Python 3.8.4 :: Something custom (64-bit)", (3, 8)),
-        ("[OS-Y 64-bit] Python 3.9.1", (3, 9)),
-    )
-    for version_str, expected in test_cases:
-      self.assertEqual(expected, utils.parse_exe_version_string(version_str))
-
-  def test_get_python_exe_version(self):
-    version = utils.get_python_exe_version(["python"])
-    self.assertIsInstance(version, tuple)
-    self.assertEqual(len(version), 2)
-
-  def test_custom_python_exe(self):
-    temp = utils._CUSTOM_PYTHON_EXES
-    # Since the logic for getting a custom exe checks for the file's existence
-    # in the pytype/ src directory, we pick an existing file to pretend to be a
-    # Python exe.
-    utils._CUSTOM_PYTHON_EXES = {(3, 10): "utils.py"}
-    (exe,), = utils.get_python_exes((3, 10))
-    self.assertEqual(os.path.basename(exe), "utils.py")
-    utils._CUSTOM_PYTHON_EXES = temp
-
 
 def _make_tuple(x):
   return tuple(range(x))
